[prev in list] [next in list] [prev in thread] [next in thread] 

List:       linux-ntfs-cvs
Subject:    [Linux-NTFS-cvs] CVS: linux-ntfs/include attrib.h,1.34,1.35 mft.h,1.32,1.33 volume.h,1.19,1.20
From:       Anton Altaparmakov <antona () users ! sourceforge ! net>
Date:       2002-04-27 19:49:11
[Download RAW message or body]


Changes by: antona

Update of /cvsroot/linux-ntfs/linux-ntfs/include
In directory usw-pr-cvs1:/tmp/cvs-serv24579/include

Modified Files:
	attrib.h mft.h volume.h 
Log Message:
Update library, new APIs ntfs_attr_find_vcn(), misc fixes and cleanups, make all the \
utilities compile, fix bugs I noticed in ntfslabel and it now works properly.


Index: attrib.h
===================================================================
RCS file: /cvsroot/linux-ntfs/linux-ntfs/include/attrib.h,v
retrieving revision 1.34
retrieving revision 1.35
diff -U2 -r1.34 -r1.35
--- attrib.h	24 Apr 2002 23:47:42 -0000	1.34
+++ attrib.h	27 Apr 2002 19:49:09 -0000	1.35
@@ -146,4 +146,14 @@
 extern void ntfs_attr_put(ntfs_attr *na);
 
+extern int ntfs_attr_read(const ntfs_attr *na, const __s64 pos,
+		const __s64 bk_cnt, const __u32 bk_size, void *dst);
+extern int ntfs_attr_write(const ntfs_attr *na, const __s64 pos,
+		const __s64 bk_cnt, const __u32 bk_size, void *src);
+
+extern int ntfs_attr_mst_read(const ntfs_attr *na, const __s64 pos,
+		const __s64 bk_cnt, const __u32 bk_size, void *dst);
+extern int ntfs_attr_mst_write(const ntfs_attr *na, const __s64 pos,
+		const __s64 bk_cnt, const __u32 bk_size, void *src);
+
 extern run_list_element *ntfs_merge_run_lists(run_list_element *drl,
 		run_list_element *srl);
@@ -156,4 +166,5 @@
 extern LCN ntfs_rl_vcn_to_lcn(const run_list_element *rl, const VCN vcn);
 extern LCN ntfs_attr_vcn_to_lcn(ntfs_attr *na, const VCN vcn);
+extern run_list_element *ntfs_attr_find_vcn(ntfs_attr *na, const VCN vcn);
 
 // FIXME / TODO: Above here the file is cleaned up. (AIA)

Index: volume.h
===================================================================
RCS file: /cvsroot/linux-ntfs/linux-ntfs/include/volume.h,v
retrieving revision 1.19
retrieving revision 1.20
diff -U2 -r1.19 -r1.20
--- volume.h	23 Apr 2002 23:27:33 -0000	1.19
+++ volume.h	27 Apr 2002 19:49:09 -0000	1.20
@@ -60,7 +60,8 @@
 	__u32 mft_record_size;	/* Byte size of a mft record. */
 	__s64 mft_lcn;		/* Logical cluster number of the data attribute
-				   for FILE_Mft. */
+				   for FILE_MFT. */
        	__s64 mftmirr_lcn;	/* Logical cluster number of the data attribute
-				   for FILE_MftMirr. */
+				   for FILE_MFTMirr. */
+	int mftmirr_size;	/* Size of the FILE_MFTMirr in mft records. */
 	__u8 cluster_size_bits;	/* Log(2) of the byte size of a cluster. */
 	__u8 mft_record_size_bits;/* Log(2) of the byte size of a mft record. */
@@ -70,10 +71,12 @@
 				   that the cluster is in use and a zero bit
 				   means the cluster is free. */
-	__u8 *mft_bitmap;	/* Value of bitmap attribute of FILE_Mft. Has
+	__u8 *mft_bitmap;	/* Value of bitmap attribute of FILE_MFT. Has
 				   same interpretation as the lcn_bitmap above
 				   but except that it keeps track of the usage
 				   of the mft records rather than the lcns. */
 	run_list *mft_rl;	/* Decompressed run list of the data attribute
-				   of FILE_Mft. */
+				   of FILE_MFT. */
+	run_list *mftmirr_rl;	/* Decompressed run list of the data attribute
+				   of FILE_MFTMirr. */
 	__s64 number_of_mft_records;	/* Number of records in the mft, equals
 					   the number of bits in mft_bitmap. */


_______________________________________________
Linux-NTFS-cvs mailing list
Linux-NTFS-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/linux-ntfs-cvs


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
Index: mft.h
===================================================================
RCS file: /cvsroot/linux-ntfs/linux-ntfs/include/mft.h,v
retrieving revision 1.32
retrieving revision 1.33
diff -U2 -r1.32 -r1.33
--- mft.h	20 Apr 2002 23:09:42 -0000	1.32
+++ mft.h	27 Apr 2002 19:49:09 -0000	1.33
@@ -79,5 +79,5 @@
 
 /**
  * get_mft_record_data_size - return number of bytes used in mft record @b
  * @m:		mft record to get the data size of
  *
@@ -94,5 +94,5 @@
  * NTFS driver/chkdsk wouldn't view this as corruption in itself though).
  */
-static __inline__ __u32 get_mft_record_data_size(const MFT_RECORD *m)
+static __inline__ __u32 ntfs_get_mft_record_data_size(const MFT_RECORD *m)
 {
 	if (!m || !is_mft_record(m->magic))
@@ -79,5 +79,5 @@
 
 /**
- * get_mft_record_data_size - return number of bytes used in mft record @b
+ * ntfs_get_mft_record_data_size - return number of bytes used in mft record @b
  * @m:		mft record to get the data size of
  *
